@@ -208,7 +208,7 @@ class Config:
         Defaults to False.
 
     :type request_min_compression_size_bytes: int
-    :param request_min_compression_bytes: The minimum size in bytes that a
+    :param request_min_compression_size_bytes: The minimum size in bytes that a
         request body should be to trigger compression. All requests with
         streaming input that don't contain the ``requiresLength`` trait will be
         compressed regardless of this setting.
@@ -219,6 +219,21 @@ class Config:
     :param disable_request_compression: Disables request body compression if
         set to True.
 
+        Defaults to None.
+
+    :type sigv4a_signing_region_set: string
+    :param sigv4a_signing_region_set: A set of AWS regions to apply the signature for
+        when using SigV4a for signing. Set to ``*`` to represent all regions.
+
+        Defaults to None.
+
+    :type client_context_params: dict
+    :param client_context_params: A dictionary of parameters specific to
+        individual services. If available, valid parameters can be found in
+        the ``Client Context Parameters`` section of the service client's
+        documentation. Invalid parameters or ones that are not used by the
+        specified service will be ignored.
+
         Defaults to None.
     """
 
@@ -247,6 +262,8 @@ class Config:
             ('tcp_keepalive', None),
             ('request_min_compression_size_bytes', None),
             ('disable_request_compression', None),
+            ('client_context_params', None),
+            ('sigv4a_signing_region_set', None),
         ]
     )
 
@@ -300,7 +317,7 @@ class Config:
         # Iterate through the args passed through to the constructor and map
         # them to appropriate keys.
         for i, arg in enumerate(args):
-            # If it a kwarg was specified for the arg, then error out
+            # If a kwarg was specified for the arg, then error out
             if option_order[i] in user_provided_options:
                 raise TypeError(
                     f"Got multiple values for keyword argument '{option_order[i]}'"
